@@ -12,43 +12,31 @@
 
 using namespace GraphTheory;
 
-class GraphTheory::NodeModelPrivate {
+class GraphTheory::NodeModelPrivate
+{
 public:
-    NodeModelPrivate()
-        : m_signalMapper(new QSignalMapper)
-    {
-    }
-
-    ~NodeModelPrivate()
-    {
-        m_signalMapper->deleteLater();
-    }
-
     void updateMappings()
     {
         int nodes = m_document->nodes().count();
         for (int i = 0; i < nodes; i++) {
-            m_signalMapper->setMapping(m_document->nodes().at(i).data(), i);
+            m_signalMapper.setMapping(m_document->nodes().at(i).data(), i);
         }
     }
 
     GraphDocumentPtr m_document;
-    QSignalMapper *m_signalMapper;
+    QSignalMapper m_signalMapper;
 };
 
 NodeModel::NodeModel(QObject *parent)
     : QAbstractListModel(parent)
     , d(new NodeModelPrivate)
 {
-    connect(d->m_signalMapper, static_cast<void (QSignalMapper::*)(int)>(&QSignalMapper::mapped), this, &NodeModel::emitNodeChanged);
+    connect(&d->m_signalMapper, &QSignalMapper::mappedInt, this, &NodeModel::emitNodeChanged);
 }
 
-NodeModel::~NodeModel()
-{
+NodeModel::~NodeModel() = default;
 
-}
-
-QHash< int, QByteArray > NodeModel::roleNames() const
+QHash<int, QByteArray> NodeModel::roleNames() const
 {
     QHash<int, QByteArray> roles;
     roles[IdRole] = "id";
@@ -91,12 +79,11 @@ QVariant NodeModel::data(const QModelIndex &index, int role) const
 
     NodePtr const node = d->m_document->nodes().at(index.row());
 
-    switch(role)
-    {
+    switch (role) {
     case IdRole:
         return node->id();
     case DataRole:
-        return QVariant::fromValue<QObject*>(node.data());
+        return QVariant::fromValue<QObject *>(node.data());
     default:
         return QVariant();
     }
@@ -118,7 +105,7 @@ int NodeModel::rowCount(const QModelIndex &parent) const
 void NodeModel::onNodeAboutToBeAdded(NodePtr node, int index)
 {
     Q_UNUSED(node)
-    //TODO add missing signals
+    // TODO add missing signals
     beginInsertRows(QModelIndex(), index, index);
 }
 
@@ -140,8 +127,8 @@ void NodeModel::onNodesRemoved()
 
 void NodeModel::emitNodeChanged(int row)
 {
-    emit nodeChanged(row);
-    emit dataChanged(index(row, 0), index(row, 0));
+    Q_EMIT nodeChanged(row);
+    Q_EMIT dataChanged(index(row, 0), index(row, 0));
 }
 
 QVariant NodeModel::headerData(int section, Qt::Orientation orientation, int role) const
