@@ -1,27 +1,24 @@
 /*
- *  SPDX-FileCopyrightText: 2012-2014 Andreas Cord-Landwehr <cordlandwehr@kde.org>
- *  SPDX-FileCopyrightText: 2019 Tomaz Canabrava <tcanabrava@kde.org>
- *
- *  SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
- */
+    SPDX-FileCopyrightText: 2012-2014 Andreas Cord-Landwehr <cordlandwehr@kde.org>
+    SPDX-FileCopyrightText: 2019 Tomaz Canabrava <tcanabrava@kde.org>
+    SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+*/
 
 #include "sidedockwidget.h"
-
 #include <KAcceleratorManager>
+#include <KLocalizedString>
+#include <QAction>
+#include <QDebug>
+#include <QIcon>
+#include <QLabel>
+#include <QLayout>
+#include <QObject>
+#include <QStackedLayout>
 #include <QStyle>
 #include <QStyleOptionToolButton>
 #include <QStylePainter>
 #include <QToolBar>
-#include <QLabel>
-#include <QAction>
-#include <QStackedLayout>
-#include <QLayout>
-#include <QObject>
 #include <QWidget>
-#include <QIcon>
-#include <KLocalizedString>
-#include <QDebug>
-
 
 SideToolButton::SideToolButton(QWidget *parent)
     : QToolButton(parent)
@@ -31,8 +28,6 @@ SideToolButton::SideToolButton(QWidget *parent)
     setCheckable(true);
     setAutoRaise(true);
     setToolButtonStyle(Qt::ToolButtonTextBesideIcon);
-
-    wasChecked = false;
 }
 
 Qt::Orientation SideToolButton::orientation() const
@@ -62,10 +57,7 @@ QSize SideToolButton::sizeHint() const
     const int iconheight = option.iconSize.width();
 
     // compute final size. height and width are rotated.
-    return {
-        4 + qMax(textSize.height(), iconheight) + spacing,
-        4 + textSize.width() + iconwidth + spacing
-    };
+    return {4 + qMax(textSize.height(), iconheight) + spacing, 4 + textSize.width() + iconwidth + spacing};
 }
 
 void SideToolButton::paintEvent(QPaintEvent *event)
@@ -102,10 +94,9 @@ void SideToolButton::paintEvent(QPaintEvent *event)
     painter.end();
 }
 
-SidedockWidget::SidedockWidget(QWidget* parent)
+SidedockWidget::SidedockWidget(QWidget *parent)
     : QWidget(parent)
     , _btnGroup(new QButtonGroup(this))
-    , _showDock(false)
 {
     Q_ASSERT(parent); // we need a parent widget
 
@@ -115,63 +106,47 @@ SidedockWidget::SidedockWidget(QWidget* parent)
     _toolBar->setFloatable(false);
     _toolBar->setMovable(false);
     _toolBar->setObjectName("sidebar");
-    _toolBar->setIconSize(QSize(16,16));
+    _toolBar->setIconSize(QSize(16, 16));
     _toolBar->setContextMenuPolicy(Qt::PreventContextMenu);
     setLayout(new QStackedLayout);
+
+    connect(_btnGroup, &QButtonGroup::idClicked, this, [this](int index) {
+        auto *stackLayout = qobject_cast<QStackedLayout *>(layout());
+        if (stackLayout->currentIndex() == index) {
+            setVisible(!isVisible());
+        } else {
+            auto *stackLayout = qobject_cast<QStackedLayout *>(layout());
+            stackLayout->setCurrentIndex(index);
+            setVisible(true);
+        }
+    });
 }
 
-void SidedockWidget::addDock(QWidget* widget, const QString& title, const QIcon& icon)
+void SidedockWidget::addDock(QWidget *widget, const QString &title, const QIcon &icon)
 {
     widget->setVisible(false);
     layout()->addWidget(widget);
 
-    SideToolButton* button = new SideToolButton(this);
+    SideToolButton *button = new SideToolButton(this);
 
     button->setText(title);
     button->setToolTip(i18n("Toggle '%1' view.", title));
     button->setIcon(icon);
     button->setShortcut(QKeySequence());
     button->setChecked(false); // initially do not check
+    const int index = _widgets.count();
+    _btnGroup->addButton(button, index);
 
-    _btnGroup->addButton(button);
-
-    // only request action on user set action
-    const int idx = _widgets.count();
-
-    connect(button, &SideToolButton::clicked, this,
-        [this, button, idx] {
-
-        // Force uncheck the button because of the exclusive
-        // Without this the toolbar buttons cannot be all unchecked
-        // after one is clicked4
-        if (button->wasChecked) {
-            _btnGroup->setExclusive(false);
-            button->setChecked(false);
-            _btnGroup->setExclusive(true);
-
-            button->wasChecked = false;
-        } else {
-            button->wasChecked = true;
-        }
-
-        showDock(button->isChecked(), idx);
-    });
+    if (index == 0) { // set widget of ElementTypes as standard
+        button->setChecked(true);
+    }
 
     // register and add to list
     _toolBar->addWidget(button);
     _widgets.append(widget);
 }
 
-void SidedockWidget::showDock(bool show, int nr)
-{
-    _showDock = show;
-    setVisible(show);
-    auto *stackLayout = qobject_cast<QStackedLayout*>(layout());
-    stackLayout->setCurrentIndex(nr);
-    Q_EMIT visibilityChanged(show);
-}
-
-QToolBar* SidedockWidget::toolbar() const
+QToolBar *SidedockWidget::toolbar() const
 {
     return _toolBar;
 }
